@@ -1,7 +1,14 @@
 
 ##LYRA MODULE
 
-
+from pymodbus.client.sync import ModbusSerialClient
+from pymodbus import payload
+from pymodbus.payload import BinaryPayloadDecoder
+from pymodbus.payload import BinaryPayloadBuilder
+from pymodbus.constants import Endian
+from pymodbus.utilities import computeCRC
+import numpy as np
+import time
 
 def reset_Lyra(client,target_unit):
     try:
